==> qgis_2.14.5+dfsg.orig.tar.bz2: qgis-2.14.5/src/gui/editorwidgets/qgswebviewconfigdlg.h <==
/***************************************************************************
    qgswebviewwidgetconfigdlgbase.h
     --------------------------------------
    Date                 : 11.1.2014
    Copyright            : (C) 2014 Matthias Kuhn
    Email                : matthias at opengis dot ch
 ***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef QGSWEBVIEWWIDGETCONFIGDLGBASE_H
#define QGSWEBVIEWWIDGETCONFIGDLGBASE_H

#include "ui_qgswebviewconfigdlgbase.h"

#include "qgseditorconfigwidget.h"

/** \class QgsWebViewWidgetConfigDlg
 * \note not available in Python bindings
 */

class GUI_EXPORT QgsWebViewWidgetConfigDlg : public QgsEditorConfigWidget, private Ui::QgsWebViewWidgetConfigDlgBase
{
    Q_OBJECT

  public:
    explicit QgsWebViewWidgetConfigDlg( QgsVectorLayer* vl, int fieldIdx, QWidget *parent );

    // QgsEditorConfigWidget interface
  public:
    QgsEditorWidgetConfig config() override;
    void setConfig( const QgsEditorWidgetConfig& config ) override;
};

#endif // QGSWEBVIEWWIDGETCONFIGDLGBASE_H

==> qgis_2.18.28+dfsg.orig.tar.bz2: qgis-2.18.28/src/gui/editorwidgets/qgswebviewconfigdlg.h <==
/***************************************************************************
    qgswebviewwidgetconfigdlgbase.h
     --------------------------------------
    Date                 : 11.1.2014
    Copyright            : (C) 2014 Matthias Kuhn
    Email                : matthias at opengis dot ch
 ***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef QGSWEBVIEWWIDGETCONFIGDLGBASE_H
#define QGSWEBVIEWWIDGETCONFIGDLGBASE_H

#include "ui_qgswebviewconfigdlgbase.h"

#include "qgseditorconfigwidget.h"

/** \ingroup gui
 * \class QgsWebViewWidgetConfigDlg
 * \note not available in Python bindings
 */

class GUI_EXPORT QgsWebViewWidgetConfigDlg : public QgsEditorConfigWidget, private Ui::QgsWebViewWidgetConfigDlgBase
{
    Q_OBJECT

  public:
    explicit QgsWebViewWidgetConfigDlg( QgsVectorLayer* vl, int fieldIdx, QWidget *parent );

    // QgsEditorConfigWidget interface
  public:
    QgsEditorWidgetConfig config() override;
    void setConfig( const QgsEditorWidgetConfig& config ) override;
};

#endif // QGSWEBVIEWWIDGETCONFIGDLGBASE_H
